# Meterviewer

Meter Data viewer, not only to view multiple dataset via notebook.

## Features

1. Meter Image generation.
2. Generate jsondb for meter dataset.
3. Generate sqlite.db for meter dataset.
4. View the dataset with streamlit.

## Install

`pip install meterviewer`

## Development

我们使用 [uv](https://github.com/astral-sh/uv) 来管理项目。

- 要安装 uv，运行 `python3 -m pip install uv`。
- 要安装依赖，运行 `uv sync`。

## Documentation

We use [sphinx](https://www.sphinx-doc.org/en/master/) for documentation.

## Notes

1. Pure functional is critial. Less things to worry about.
